==> SingleRBook_1.17.1.tar.gz: SingleRBook/inst/doc/book/pancreas.md <==
---
bibliography: ref.bib
---

# (PART) Case studies {-}

# Cross-annotating human pancreas {#pancreas-case-study}

<script>
document.addEventListener("click", function (event) {
    if (event.target.classList.contains("rebook-collapse")) {
        event.target.classList.toggle("active");
        var content = event.target.nextElementSibling;
        if (content.style.display === "block") {
            content.style.display = "none";
        } else {
            content.style.display = "block";
        }
    }
})
</script>

<style>
.rebook-collapse {
  background-color: #eee;
  color: #444;
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
}

.rebook-content {
  padding: 0 18px;
  display: none;
  overflow: hidden;
  background-color: #f1f1f1;
}
</style>

## Loading the data

We load the @muraro2016singlecell dataset as our reference, removing unlabelled cells or cells without a clear label.


``` r
library(scRNAseq)
sceM <- MuraroPancreasData()
sceM <- sceM[,!is.na(sceM$label) & sceM$label!="unclear"] 
```

We compute log-expression values for use in marker detection inside `SingleR()`.


``` r
library(scater)
sceM <- logNormCounts(sceM)
```

We examine the distribution of labels in this reference.


``` r
table(sceM$label)
```

```
## 
##      acinar       alpha        beta       delta        duct endothelial 
##         219         812         448         193         245          21 
##     epsilon mesenchymal          pp 
##           3          80         101
```

We load the @grun2016denovo dataset as our test,
applying some basic quality control to remove low-quality cells in some of the batches
(see [here](https://osca.bioconductor.org/grun-human-pancreas-cel-seq2.html#quality-control-8) for details).


``` r
sceG <- GrunPancreasData()

sceG <- addPerCellQC(sceG)
qc <- quickPerCellQC(colData(sceG), 
    percent_subsets="altexps_ERCC_percent",
    batch=sceG$donor,
    subset=sceG$donor %in% c("D17", "D7", "D2"))
sceG <- sceG[,!qc$discard]
```

Technically speaking, the test dataset does not need log-expression values but we compute them anyway for convenience.


``` r
sceG <- logNormCounts(sceG)
```

## Applying the annotation

We apply `SingleR()` with Wilcoxon rank sum test-based marker detection to annotate the Grun dataset with the Muraro labels.


``` r
library(SingleR)
pred.grun <- SingleR(test=sceG, ref=sceM, labels=sceM$label, de.method="wilcox")
```

We examine the distribution of predicted labels:


``` r
table(pred.grun$labels)
```

```
## 
##      acinar       alpha        beta       delta        duct endothelial 
##         289         201         178          54         295           5 
##     epsilon mesenchymal          pp 
##           1          23          18
```

We can also examine the number of discarded cells for each label:


``` r
table(Label=pred.grun$labels,
    Lost=is.na(pred.grun$pruned.labels))
```

```
##              Lost
## Label         FALSE TRUE
##   acinar        260   29
##   alpha         200    1
##   beta          177    1
##   delta          52    2
##   duct          291    4
##   endothelial     5    0
##   epsilon         1    0
##   mesenchymal    22    1
##   pp             18    0
```

## Diagnostics

We visualize the assignment scores for each label in Figure \@ref(fig:unref-pancreas-score-heatmap).


``` r
plotScoreHeatmap(pred.grun)
```

<div class="figure">
<img src="pancreas_files/figure-html/unref-pancreas-score-heatmap-1.png" alt="Heatmap of the (normalized) assignment scores for each cell (column) in the Grun test dataset with respect to each label (row) in the Muraro reference dataset. The final assignment for each cell is shown in the annotation bar at the top." width="672" />
<p class="caption">(\#fig:unref-pancreas-score-heatmap)Heatmap of the (normalized) assignment scores for each cell (column) in the Grun test dataset with respect to each label (row) in the Muraro reference dataset. The final assignment for each cell is shown in the annotation bar at the top.</p>
</div>

The delta for each cell is visualized in Figure \@ref(fig:unref-pancreas-delta-dist).


``` r
plotDeltaDistribution(pred.grun)
```

<div class="figure">
<img src="pancreas_files/figure-html/unref-pancreas-delta-dist-1.png" alt="Distributions of the deltas for each cell in the Grun dataset assigned to each label in the Muraro dataset. Each cell is represented by a point; low-quality assignments that were pruned out are colored in orange." width="672" />
<p class="caption">(\#fig:unref-pancreas-delta-dist)Distributions of the deltas for each cell in the Grun dataset assigned to each label in the Muraro dataset. Each cell is represented by a point; low-quality assignments that were pruned out are colored in orange.</p>
</div>

Finally, we visualize the heatmaps of the marker genes for each label in Figure \@ref(fig:unref-pancreas-marker-heat).


``` r
library(scater)
collected <- list()
all.markers <- metadata(pred.grun)$de.genes

sceG$labels <- pred.grun$labels
for (lab in unique(pred.grun$labels)) {
    collected[[lab]] <- plotHeatmap(sceG, silent=TRUE, 
        order_columns_by="labels", main=lab,
        features=unique(unlist(all.markers[[lab]])))[[4]] 
}
do.call(gridExtra::grid.arrange, collected)
```

<div class="figure">
<img src="pancreas_files/figure-html/unref-pancreas-marker-heat-1.png" alt="Heatmaps of log-expression values in the Grun dataset for all marker genes upregulated in each label in the Muraro reference dataset. Assigned labels for each cell are shown at the top of each plot." width="1920" />
<p class="caption">(\#fig:unref-pancreas-marker-heat)Heatmaps of log-expression values in the Grun dataset for all marker genes upregulated in each label in the Muraro reference dataset. Assigned labels for each cell are shown at the top of each plot.</p>
</div>

## Comparison to clusters

For comparison, we will perform a quick unsupervised analysis of the Grun dataset.
We model the variances using the spike-in data and we perform graph-based clustering
(increasing the resolution by dropping `k=5`).


``` r
library(scran)
decG <- modelGeneVarWithSpikes(sceG, "ERCC")

set.seed(1000100)
sceG <- denoisePCA(sceG, decG)

library(bluster)
sceG$cluster <- clusterRows(reducedDim(sceG), NNGraphParam(k=5))
```

We see that the clusters map reasonably well to the labels in Figure \@ref(fig:unref-pancreas-label-clusters).


``` r
tab <- table(cluster=sceG$cluster, label=pred.grun$labels) 
pheatmap::pheatmap(log10(tab+10))
```

<div class="figure">
<img src="pancreas_files/figure-html/unref-pancreas-label-clusters-1.png" alt="Heatmap of the log-transformed number of cells in each combination of label (column) and cluster (row) in the Grun dataset." width="672" />
<p class="caption">(\#fig:unref-pancreas-label-clusters)Heatmap of the log-transformed number of cells in each combination of label (column) and cluster (row) in the Grun dataset.</p>
</div>



We proceed to the most important part of the analysis.
Yes, that's right, the $t$-SNE plot (Figure \@ref(fig:unref-pancreas-label-tsne)).


``` r
set.seed(101010100)
sceG <- runTSNE(sceG, dimred="PCA")
plotTSNE(sceG, colour_by="cluster", text_colour="red",
    text_by=I(pred.grun$labels))
```

<div class="figure">
<img src="pancreas_files/figure-html/unref-pancreas-label-tsne-1.png" alt="$t$-SNE plot of the Grun dataset, where each point is a cell and is colored by the assigned cluster. Reference labels from the Muraro dataset are also placed on the median coordinate across all cells assigned with that label." width="672" />
<p class="caption">(\#fig:unref-pancreas-label-tsne)$t$-SNE plot of the Grun dataset, where each point is a cell and is colored by the assigned cluster. Reference labels from the Muraro dataset are also placed on the median coordinate across all cells assigned with that label.</p>
</div>

## Session information {-}

<button class="rebook-collapse">View session info</button>
<div class="rebook-content">
```
R Under development (unstable) (2024-10-21 r87258)
Platform: x86_64-pc-linux-gnu
Running under: Ubuntu 24.04.1 LTS

Matrix products: default
BLAS:   /home/biocbuild/bbs-3.21-bioc/R/lib/libRblas.so 
LAPACK: /usr/lib/x86_64-linux-gnu/lapack/liblapack.so.3.12.0

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_GB              LC_COLLATE=C              
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

time zone: America/New_York
tzcode source: system (glibc)

attached base packages:
[1] stats4    stats     graphics  grDevices utils     datasets  methods  
[8] base     

other attached packages:
 [1] bluster_1.17.0              scran_1.35.0               
 [3] SingleR_2.9.1               scater_1.35.0              
 [5] ggplot2_3.5.1               scuttle_1.17.0             
 [7] scRNAseq_2.21.0             SingleCellExperiment_1.29.1
 [9] SummarizedExperiment_1.37.0 Biobase_2.67.0             
[11] GenomicRanges_1.59.1        GenomeInfoDb_1.43.1        
[13] IRanges_2.41.1              S4Vectors_0.45.2           
[15] BiocGenerics_0.53.3         generics_0.1.3             
[17] MatrixGenerics_1.19.0       matrixStats_1.4.1          
[19] BiocStyle_2.35.0            rebook_1.17.0              

loaded via a namespace (and not attached):
  [1] RColorBrewer_1.1-3        jsonlite_1.8.9           
  [3] CodeDepends_0.6.6         magrittr_2.0.3           
  [5] ggbeeswarm_0.7.2          GenomicFeatures_1.59.1   
  [7] gypsum_1.3.0              farver_2.1.2             
  [9] rmarkdown_2.29            BiocIO_1.17.0            
 [11] zlibbioc_1.53.0           vctrs_0.6.5              
 [13] DelayedMatrixStats_1.29.0 memoise_2.0.1            
 [15] Rsamtools_2.23.0          RCurl_1.98-1.16          
 [17] htmltools_0.5.8.1         S4Arrays_1.7.1           
 [19] AnnotationHub_3.15.0      curl_6.0.1               
 [21] BiocNeighbors_2.1.0       Rhdf5lib_1.29.0          
 [23] SparseArray_1.7.2         rhdf5_2.51.0             
 [25] sass_0.4.9                alabaster.base_1.7.2     
 [27] bslib_0.8.0               alabaster.sce_1.7.0      
 [29] httr2_1.0.6               cachem_1.1.0             
 [31] GenomicAlignments_1.43.0  igraph_2.1.1             
 [33] lifecycle_1.0.4           pkgconfig_2.0.3          
 [35] rsvd_1.0.5                Matrix_1.7-1             
 [37] R6_2.5.1                  fastmap_1.2.0            
 [39] GenomeInfoDbData_1.2.13   digest_0.6.37            
 [41] colorspace_2.1-1          AnnotationDbi_1.69.0     
 [43] dqrng_0.4.1               irlba_2.3.5.1            
 [45] ExperimentHub_2.15.0      RSQLite_2.3.8            
 [47] beachmat_2.23.1           labeling_0.4.3           
 [49] filelock_1.0.3            fansi_1.0.6              
 [51] httr_1.4.7                abind_1.4-8              
 [53] compiler_4.5.0            bit64_4.5.2              
 [55] withr_3.0.2               BiocParallel_1.41.0      
 [57] viridis_0.6.5             DBI_1.2.3                
 [59] HDF5Array_1.35.1          alabaster.ranges_1.7.0   
 [61] alabaster.schemas_1.7.0   rappdirs_0.3.3           
 [63] DelayedArray_0.33.2       rjson_0.2.23             
 [65] tools_4.5.0               vipor_0.4.7              
 [67] beeswarm_0.4.0            glue_1.8.0               
 [69] restfulr_0.0.15           rhdf5filters_1.19.0      
 [71] grid_4.5.0                Rtsne_0.17               
 [73] cluster_2.1.6             gtable_0.3.6             
 [75] ensembldb_2.31.0          metapod_1.15.0           
 [77] BiocSingular_1.23.0       ScaledMatrix_1.15.0      
 [79] utf8_1.2.4                XVector_0.47.0           
 [81] ggrepel_0.9.6             BiocVersion_3.21.1       
 [83] pillar_1.9.0              limma_3.63.2             
 [85] dplyr_1.1.4               BiocFileCache_2.15.0     
 [87] lattice_0.22-6            rtracklayer_1.67.0       
 [89] bit_4.5.0                 tidyselect_1.2.1         
 [91] locfit_1.5-9.10           Biostrings_2.75.1        
 [93] knitr_1.49                gridExtra_2.3            
 [95] scrapper_1.1.4            bookdown_0.41            
 [97] ProtGenerics_1.39.0       edgeR_4.5.0              
 [99] xfun_0.49                 statmod_1.5.0            
[101] pheatmap_1.0.12           UCSC.utils_1.3.0         
[103] lazyeval_0.2.2            yaml_2.3.10              
[105] evaluate_1.0.1            codetools_0.2-20         
[107] tibble_3.2.1              alabaster.matrix_1.7.0   
[109] BiocManager_1.30.25       graph_1.85.0             
[111] cli_3.6.3                 munsell_0.5.1            
[113] jquerylib_0.1.4           Rcpp_1.0.13-1            
[115] dir.expiry_1.15.0         dbplyr_2.5.0             
[117] png_0.1-8                 XML_3.99-0.17            
[119] parallel_4.5.0            blob_1.2.4               
[121] AnnotationFilter_1.31.0   sparseMatrixStats_1.19.0 
[123] bitops_1.0-9              viridisLite_0.4.2        
[125] alabaster.se_1.7.0        scales_1.3.0             
[127] crayon_1.5.3              rlang_1.1.4              
[129] cowplot_1.1.3             KEGGREST_1.47.0          
```
</div>

==> SingleRBook_1.18.0.tar.gz: SingleRBook/inst/doc/book/pancreas.md <==
---
bibliography: ref.bib
---

# (PART) Case studies {-}

# Cross-annotating human pancreas {#pancreas-case-study}

<script>
document.addEventListener("click", function (event) {
    if (event.target.classList.contains("rebook-collapse")) {
        event.target.classList.toggle("active");
        var content = event.target.nextElementSibling;
        if (content.style.display === "block") {
            content.style.display = "none";
        } else {
            content.style.display = "block";
        }
    }
})
</script>

<style>
.rebook-collapse {
  background-color: #eee;
  color: #444;
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
}

.rebook-content {
  padding: 0 18px;
  display: none;
  overflow: hidden;
  background-color: #f1f1f1;
}
</style>

## Loading the data

We load the @muraro2016singlecell dataset as our reference, removing unlabelled cells or cells without a clear label.


``` r
library(scRNAseq)
sceM <- MuraroPancreasData()
sceM <- sceM[,!is.na(sceM$label) & sceM$label!="unclear"] 
```

We compute log-expression values for use in marker detection inside `SingleR()`.


``` r
library(scater)
sceM <- logNormCounts(sceM)
```

We examine the distribution of labels in this reference.


``` r
table(sceM$label)
```

```
## 
##      acinar       alpha        beta       delta        duct endothelial 
##         219         812         448         193         245          21 
##     epsilon mesenchymal          pp 
##           3          80         101
```

We load the @grun2016denovo dataset as our test,
applying some basic quality control to remove low-quality cells in some of the batches
(see [here](https://osca.bioconductor.org/grun-human-pancreas-cel-seq2.html#quality-control-8) for details).


``` r
sceG <- GrunPancreasData()

sceG <- addPerCellQC(sceG)
qc <- quickPerCellQC(colData(sceG), 
    percent_subsets="altexps_ERCC_percent",
    batch=sceG$donor,
    subset=sceG$donor %in% c("D17", "D7", "D2"))
sceG <- sceG[,!qc$discard]
```

Technically speaking, the test dataset does not need log-expression values but we compute them anyway for convenience.


``` r
sceG <- logNormCounts(sceG)
```

## Applying the annotation

We apply `SingleR()` with Wilcoxon rank sum test-based marker detection to annotate the Grun dataset with the Muraro labels.


``` r
library(SingleR)
pred.grun <- SingleR(test=sceG, ref=sceM, labels=sceM$label, de.method="wilcox")
```

We examine the distribution of predicted labels:


``` r
table(pred.grun$labels)
```

```
## 
##      acinar       alpha        beta       delta        duct endothelial 
##         289         201         178          54         295           5 
##     epsilon mesenchymal          pp 
##           1          23          18
```

We can also examine the number of discarded cells for each label:


``` r
table(Label=pred.grun$labels,
    Lost=is.na(pred.grun$pruned.labels))
```

```
##              Lost
## Label         FALSE TRUE
##   acinar        260   29
##   alpha         200    1
##   beta          177    1
##   delta          52    2
##   duct          291    4
##   endothelial     5    0
##   epsilon         1    0
##   mesenchymal    22    1
##   pp             18    0
```

## Diagnostics

We visualize the assignment scores for each label in Figure \@ref(fig:unref-pancreas-score-heatmap).


``` r
plotScoreHeatmap(pred.grun)
```

<div class="figure">
<img src="pancreas_files/figure-html/unref-pancreas-score-heatmap-1.png" alt="Heatmap of the (normalized) assignment scores for each cell (column) in the Grun test dataset with respect to each label (row) in the Muraro reference dataset. The final assignment for each cell is shown in the annotation bar at the top." width="672" />
<p class="caption">(\#fig:unref-pancreas-score-heatmap)Heatmap of the (normalized) assignment scores for each cell (column) in the Grun test dataset with respect to each label (row) in the Muraro reference dataset. The final assignment for each cell is shown in the annotation bar at the top.</p>
</div>

The delta for each cell is visualized in Figure \@ref(fig:unref-pancreas-delta-dist).


``` r
plotDeltaDistribution(pred.grun)
```

<div class="figure">
<img src="pancreas_files/figure-html/unref-pancreas-delta-dist-1.png" alt="Distributions of the deltas for each cell in the Grun dataset assigned to each label in the Muraro dataset. Each cell is represented by a point; low-quality assignments that were pruned out are colored in orange." width="672" />
<p class="caption">(\#fig:unref-pancreas-delta-dist)Distributions of the deltas for each cell in the Grun dataset assigned to each label in the Muraro dataset. Each cell is represented by a point; low-quality assignments that were pruned out are colored in orange.</p>
</div>

Finally, we visualize the heatmaps of the marker genes for each label in Figure \@ref(fig:unref-pancreas-marker-heat).


``` r
library(scater)
collected <- list()
all.markers <- metadata(pred.grun)$de.genes

sceG$labels <- pred.grun$labels
for (lab in unique(pred.grun$labels)) {
    collected[[lab]] <- plotHeatmap(sceG, silent=TRUE, 
        order_columns_by="labels", main=lab,
        features=unique(unlist(all.markers[[lab]])))[[4]] 
}
do.call(gridExtra::grid.arrange, collected)
```

<div class="figure">
<img src="pancreas_files/figure-html/unref-pancreas-marker-heat-1.png" alt="Heatmaps of log-expression values in the Grun dataset for all marker genes upregulated in each label in the Muraro reference dataset. Assigned labels for each cell are shown at the top of each plot." width="1920" />
<p class="caption">(\#fig:unref-pancreas-marker-heat)Heatmaps of log-expression values in the Grun dataset for all marker genes upregulated in each label in the Muraro reference dataset. Assigned labels for each cell are shown at the top of each plot.</p>
</div>

## Comparison to clusters

For comparison, we will perform a quick unsupervised analysis of the Grun dataset.
We model the variances using the spike-in data and we perform graph-based clustering
(increasing the resolution by dropping `k=5`).


``` r
library(scran)
decG <- modelGeneVarWithSpikes(sceG, "ERCC")

set.seed(1000100)
sceG <- denoisePCA(sceG, decG)

library(bluster)
sceG$cluster <- clusterRows(reducedDim(sceG), NNGraphParam(k=5))
```

We see that the clusters map reasonably well to the labels in Figure \@ref(fig:unref-pancreas-label-clusters).


``` r
tab <- table(cluster=sceG$cluster, label=pred.grun$labels) 
pheatmap::pheatmap(log10(tab+10))
```

<div class="figure">
<img src="pancreas_files/figure-html/unref-pancreas-label-clusters-1.png" alt="Heatmap of the log-transformed number of cells in each combination of label (column) and cluster (row) in the Grun dataset." width="672" />
<p class="caption">(\#fig:unref-pancreas-label-clusters)Heatmap of the log-transformed number of cells in each combination of label (column) and cluster (row) in the Grun dataset.</p>
</div>



We proceed to the most important part of the analysis.
Yes, that's right, the $t$-SNE plot (Figure \@ref(fig:unref-pancreas-label-tsne)).


``` r
set.seed(101010100)
sceG <- runTSNE(sceG, dimred="PCA")
plotTSNE(sceG, colour_by="cluster", text_colour="red",
    text_by=I(pred.grun$labels))
```

<div class="figure">
<img src="pancreas_files/figure-html/unref-pancreas-label-tsne-1.png" alt="$t$-SNE plot of the Grun dataset, where each point is a cell and is colored by the assigned cluster. Reference labels from the Muraro dataset are also placed on the median coordinate across all cells assigned with that label." width="672" />
<p class="caption">(\#fig:unref-pancreas-label-tsne)$t$-SNE plot of the Grun dataset, where each point is a cell and is colored by the assigned cluster. Reference labels from the Muraro dataset are also placed on the median coordinate across all cells assigned with that label.</p>
</div>

## Session information {-}

<button class="rebook-collapse">View session info</button>
<div class="rebook-content">
```
R version 4.5.0 RC (2025-04-04 r88126)
Platform: x86_64-pc-linux-gnu
Running under: Ubuntu 24.04.2 LTS

Matrix products: default
BLAS:   /home/biocbuild/bbs-3.21-bioc/R/lib/libRblas.so 
LAPACK: /usr/lib/x86_64-linux-gnu/lapack/liblapack.so.3.12.0  LAPACK version 3.12.0

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_GB              LC_COLLATE=C              
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

time zone: America/New_York
tzcode source: system (glibc)

attached base packages:
[1] stats4    stats     graphics  grDevices utils     datasets  methods  
[8] base     

other attached packages:
 [1] bluster_1.18.0              scran_1.36.0               
 [3] SingleR_2.10.0              scater_1.36.0              
 [5] ggplot2_3.5.2               scuttle_1.18.0             
 [7] scRNAseq_2.21.1             SingleCellExperiment_1.30.0
 [9] SummarizedExperiment_1.38.0 Biobase_2.68.0             
[11] GenomicRanges_1.60.0        GenomeInfoDb_1.44.0        
[13] IRanges_2.42.0              S4Vectors_0.46.0           
[15] BiocGenerics_0.54.0         generics_0.1.3             
[17] MatrixGenerics_1.20.0       matrixStats_1.5.0          
[19] BiocStyle_2.36.0            rebook_1.18.0              

loaded via a namespace (and not attached):
  [1] RColorBrewer_1.1-3        jsonlite_2.0.0           
  [3] CodeDepends_0.6.6         magrittr_2.0.3           
  [5] ggbeeswarm_0.7.2          GenomicFeatures_1.60.0   
  [7] gypsum_1.4.0              farver_2.1.2             
  [9] rmarkdown_2.29            BiocIO_1.18.0            
 [11] vctrs_0.6.5               DelayedMatrixStats_1.30.0
 [13] memoise_2.0.1             Rsamtools_2.24.0         
 [15] RCurl_1.98-1.17           htmltools_0.5.8.1        
 [17] S4Arrays_1.8.0            AnnotationHub_3.16.0     
 [19] curl_6.2.2                BiocNeighbors_2.2.0      
 [21] Rhdf5lib_1.30.0           SparseArray_1.8.0        
 [23] rhdf5_2.52.0              sass_0.4.10              
 [25] alabaster.base_1.8.0      bslib_0.9.0              
 [27] alabaster.sce_1.8.0       httr2_1.1.2              
 [29] cachem_1.1.0              GenomicAlignments_1.44.0 
 [31] igraph_2.1.4              lifecycle_1.0.4          
 [33] pkgconfig_2.0.3           rsvd_1.0.5               
 [35] Matrix_1.7-3              R6_2.6.1                 
 [37] fastmap_1.2.0             GenomeInfoDbData_1.2.14  
 [39] digest_0.6.37             colorspace_2.1-1         
 [41] AnnotationDbi_1.70.0      dqrng_0.4.1              
 [43] irlba_2.3.5.1             ExperimentHub_2.16.0     
 [45] RSQLite_2.3.9             beachmat_2.24.0          
 [47] labeling_0.4.3            filelock_1.0.3           
 [49] httr_1.4.7                abind_1.4-8              
 [51] compiler_4.5.0            bit64_4.6.0-1            
 [53] withr_3.0.2               BiocParallel_1.42.0      
 [55] viridis_0.6.5             DBI_1.2.3                
 [57] HDF5Array_1.36.0          alabaster.ranges_1.8.0   
 [59] alabaster.schemas_1.8.0   rappdirs_0.3.3           
 [61] DelayedArray_0.34.0       rjson_0.2.23             
 [63] tools_4.5.0               vipor_0.4.7              
 [65] beeswarm_0.4.0            glue_1.8.0               
 [67] h5mread_1.0.0             restfulr_0.0.15          
 [69] rhdf5filters_1.20.0       grid_4.5.0               
 [71] Rtsne_0.17                cluster_2.1.8.1          
 [73] gtable_0.3.6              ensembldb_2.32.0         
 [75] metapod_1.16.0            BiocSingular_1.24.0      
 [77] ScaledMatrix_1.16.0       XVector_0.48.0           
 [79] ggrepel_0.9.6             BiocVersion_3.21.1       
 [81] pillar_1.10.2             limma_3.64.0             
 [83] dplyr_1.1.4               BiocFileCache_2.16.0     
 [85] lattice_0.22-7            rtracklayer_1.68.0       
 [87] bit_4.6.0                 tidyselect_1.2.1         
 [89] locfit_1.5-9.12           Biostrings_2.76.0        
 [91] knitr_1.50                gridExtra_2.3            
 [93] scrapper_1.2.0            bookdown_0.43            
 [95] ProtGenerics_1.40.0       edgeR_4.6.0              
 [97] xfun_0.52                 statmod_1.5.0            
 [99] pheatmap_1.0.12           UCSC.utils_1.4.0         
[101] lazyeval_0.2.2            yaml_2.3.10              
[103] evaluate_1.0.3            codetools_0.2-20         
[105] tibble_3.2.1              alabaster.matrix_1.8.0   
[107] BiocManager_1.30.25       graph_1.86.0             
[109] cli_3.6.4                 munsell_0.5.1            
[111] jquerylib_0.1.4           Rcpp_1.0.14              
[113] dir.expiry_1.16.0         dbplyr_2.5.0             
[115] png_0.1-8                 XML_3.99-0.18            
[117] parallel_4.5.0            blob_1.2.4               
[119] AnnotationFilter_1.32.0   sparseMatrixStats_1.20.0 
[121] bitops_1.0-9              viridisLite_0.4.2        
[123] alabaster.se_1.8.0        scales_1.3.0             
[125] crayon_1.5.3              rlang_1.1.6              
[127] cowplot_1.1.3             KEGGREST_1.48.0          
```
</div>
